@@ -3,5 +3,5 @@ use strict;
 use aSb;
 
 my $p = aSb->new;
-$p->slurp_file('','Try aaabbb: ', "\n");
+$p->slurp_file('', "\n");
 $p->YYParse( yydebug => 0x1F );
