@@ -21,7 +21,7 @@ our ( $VERSION, $COMPATIBLE, $FILENAME );
 
 
 # $VERSION is also in Parse/Eyapp.pm
-$VERSION = "1.180";
+$VERSION = "1.181";
 $COMPATIBLE = '0.07';
 $FILENAME   =__FILE__;
 
@@ -409,7 +409,7 @@ sub YYPreParse {
   my $rp = $parser->new( yyerror => sub {});
 
   my $pos  = pos(${$self->input});
-  my $rpos = $self->{POS};;
+  my $rpos = $self->{POS};
 
   #print "pos = $pos\n";
   $rp->input($self->input);
